@@ -1,9 +1,11 @@
+from __future__ import annotations
+
 import itertools
 import os
 import shlex
 import shutil
 import sys
-from typing import List, Optional, Tuple, cast
+from typing import cast
 
 import click
 from pip._internal.commands import create_command
@@ -12,7 +14,7 @@ from pip._internal.index.package_finder import PackageFinder
 from pip._internal.metadata import get_environment
 
 from .. import sync
-from .._compat import IS_CLICK_VER_8_PLUS, parse_requirements
+from .._compat import parse_requirements
 from .._compat.pip_compat import Distribution
 from ..exceptions import PipToolsError
 from ..logging import log
@@ -26,12 +28,9 @@ from ..utils import (
 
 DEFAULT_REQUIREMENTS_FILE = "requirements.txt"
 
-# TODO: drop click 7 and remove this block, pass directly to version_option
-version_option_kwargs = {"package_name": "pip-tools"} if IS_CLICK_VER_8_PLUS else {}
-
 
 @click.command(context_settings={"help_option_names": ("-h", "--help")})
-@click.version_option(**version_option_kwargs)
+@click.version_option(package_name="pip-tools")
 @click.option(
     "-a",
     "--ask",
@@ -91,19 +90,19 @@ def cli(
     ask: bool,
     dry_run: bool,
     force: bool,
-    find_links: Tuple[str, ...],
-    index_url: Optional[str],
-    extra_index_url: Tuple[str, ...],
-    trusted_host: Tuple[str, ...],
+    find_links: tuple[str, ...],
+    index_url: str | None,
+    extra_index_url: tuple[str, ...],
+    trusted_host: tuple[str, ...],
     no_index: bool,
-    python_executable: Optional[str],
+    python_executable: str | None,
     verbose: int,
     quiet: int,
     user_only: bool,
-    cert: Optional[str],
-    client_cert: Optional[str],
-    src_files: Tuple[str, ...],
-    pip_args: Optional[str],
+    cert: str | None,
+    client_cert: str | None,
+    src_files: tuple[str, ...],
+    pip_args: str | None,
 ) -> None:
     """Synchronize virtual environment with requirements.txt."""
     log.verbosity = verbose - quiet
@@ -210,14 +209,14 @@ def _validate_python_executable(python_executable: str) -> None:
 def _compose_install_flags(
     finder: PackageFinder,
     no_index: bool,
-    index_url: Optional[str],
-    extra_index_url: Tuple[str, ...],
-    trusted_host: Tuple[str, ...],
-    find_links: Tuple[str, ...],
+    index_url: str | None,
+    extra_index_url: tuple[str, ...],
+    trusted_host: tuple[str, ...],
+    find_links: tuple[str, ...],
     user_only: bool,
-    cert: Optional[str],
-    client_cert: Optional[str],
-) -> List[str]:
+    cert: str | None,
+    client_cert: str | None,
+) -> list[str]:
     """
     Compose install flags with the given finder and CLI options.
     """
@@ -272,8 +271,8 @@ def _compose_install_flags(
 def _get_installed_distributions(
     local_only: bool = True,
     user_only: bool = False,
-    paths: Optional[List[str]] = None,
-) -> List[Distribution]:
+    paths: list[str] | None = None,
+) -> list[Distribution]:
     """Return a list of installed Distribution objects."""
 
     env = get_environment(paths)
