@@ -1393,16 +1393,6 @@ def test_stdin_without_output_file(runner):
     assert "--output-file is required if input is from stdin" in out.stderr
 
 
-def test_not_specified_input_file(runner):
-    """
-    It should raise an error if there are no input files or default input files
-    such as "setup.py" or "requirements.in".
-    """
-    out = runner.invoke(cli)
-    assert "If you do not specify an input file" in out.stderr
-    assert out.exit_code == 2
-
-
 def test_stdin(pip_conf, runner):
     """
     Test compile requirements from STDIN.
@@ -1500,6 +1490,8 @@ def test_annotate_option(pip_conf, runner, options, expected):
                 """\
                 small-fake-a==0.1
                 small-fake-b==0.3
+
+                # The following packages are considered to be unsafe in a requirements file:
                 small-fake-with-deps==0.1
                 """
             ),
@@ -2457,6 +2449,49 @@ METADATA_TEST_CASES = (
 )
 
 
+@pytest.mark.network
+@pytest.mark.parametrize(("fname", "content"), METADATA_TEST_CASES)
+def test_not_specified_input_file(
+    fake_dists, runner, make_module, fname, content, monkeypatch
+):
+    """
+    Test that a default-named file is parsed if present.
+    """
+    meta_path = make_module(fname=fname, content=content)
+    monkeypatch.chdir(os.path.dirname(meta_path))
+    out = runner.invoke(
+        cli,
+        [
+            "--output-file",
+            "-",
+            "--no-header",
+            "--no-emit-options",
+            "--no-annotate",
+            "--no-build-isolation",
+            "--find-links",
+            fake_dists,
+        ],
+    )
+    monkeypatch.undo()
+
+    assert out.exit_code == 0, out.stderr
+    assert "small-fake-a==0.1\n" == out.stdout
+
+
+def test_not_specified_input_file_without_allowed_files(runner):
+    """
+    It should raise an error if there are no input files or default input files
+    such as "setup.py" or "requirements.in".
+    """
+    out = runner.invoke(cli)
+    assert out.exit_code == 2
+    expected_error = (
+        "Error: Invalid value: If you do not specify an input file, the default "
+        "is one of: requirements.in, setup.py, pyproject.toml, setup.cfg"
+    )
+    assert expected_error in out.stderr.splitlines()
+
+
 @pytest.mark.network
 @pytest.mark.parametrize(("fname", "content"), METADATA_TEST_CASES)
 def test_input_formats(fake_dists, runner, make_module, fname, content):
@@ -2736,8 +2771,36 @@ def test_print_deprecation_warning_if_using_legacy_resolver(runner, current_reso
     out = runner.invoke(cli)
     assert out.exit_code == 0, out
 
-    expected_warning = "WARNING: using legacy resolver is deprecated"
+    expected_warning = "WARNING: the legacy dependency resolver is deprecated"
     if current_resolver == "legacy":
         assert expected_warning in out.stderr
     else:
         assert expected_warning not in out.stderr
+
+
+@pytest.mark.parametrize(
+    "input_filenames",
+    (
+        pytest.param(("requirements.txt",), id="one file"),
+        pytest.param(("requirements.txt", "dev-requirements.in"), id="multiple files"),
+    ),
+)
+def test_raise_error_when_input_and_output_filenames_are_matched(
+    runner, tmp_path, input_filenames
+):
+    req_in_paths = []
+    for input_filename in input_filenames:
+        req_in = tmp_path / input_filename
+        req_in.touch()
+        req_in_paths.append(req_in.as_posix())
+
+    req_out = tmp_path / "requirements.txt"
+    req_out_path = req_out.as_posix()
+
+    out = runner.invoke(cli, req_in_paths + ["--output-file", req_out_path])
+    assert out.exit_code == 2
+
+    expected_error = (
+        f"Error: input and output filenames must not be matched: {req_out_path}"
+    )
+    assert expected_error in out.stderr.splitlines()
